package com.hw.ems.base.service;

import java.util.List;

import com.hw.ems.base.domain.BaseLineLoss;

/**
 * 线损对象信息Service接口
 *
 * @author sf
 * @date 2023-04-20
 */
public interface IBaseLineLossService {
    /**
     * 查询线损对象信息
     *
     * @param objid 线损对象信息主键
     * @return 线损对象信息
     */
    public BaseLineLoss selectBaseLineLossByObjid(Long objid);

    /**
     * 查询线损对象信息列表
     *
     * @param baseLineLoss 线损对象信息
     * @return 线损对象信息集合
     */
    public List<BaseLineLoss> selectBaseLineLossList(BaseLineLoss baseLineLoss);

    //todo 模糊查询
    List<BaseLineLoss> selectBaseLineLossListLike(BaseLineLoss baseLineLoss);
    /**
     * 新增线损对象信息
     *
     * @param baseLineLoss 线损对象信息
     * @return 结果
     */
    public int insertBaseLineLoss(BaseLineLoss baseLineLoss);

    /**
     * 修改线损对象信息
     *
     * @param baseLineLoss 线损对象信息
     * @return 结果
     */
    public int updateBaseLineLoss(BaseLineLoss baseLineLoss);

    /**
     * 批量删除线损对象信息
     *
     * @param objids 需要删除的线损对象信息主键集合
     * @return 结果
     */
    public int deleteBaseLineLossByObjids(Long[] objids);

    /**
     * 删除线损对象信息信息
     *
     * @param objid 线损对象信息主键
     * @return 结果
     */
    public int deleteBaseLineLossByObjid(Long objid);
}
